(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     53538,       1404]
NotebookOptionsPosition[     49927,       1280]
NotebookOutlinePosition[     50528,       1302]
CellTagsIndexPosition[     50485,       1299]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["A Wave Packet that Moves!", "Title",
 CellChangeTimes->{{3.569793962808854*^9, 3.569793974991797*^9}, {
  3.569888523968155*^9, 3.569888537321383*^9}, {3.570738460474923*^9, 
  3.570738482320022*^9}}],

Cell["\<\
And now let\[CloseCurlyQuote]s add time dependence...\
\>", "Text",
 CellChangeTimes->{{3.5697940524157553`*^9, 3.569794054293025*^9}, {
  3.569794827861635*^9, 3.569794925241199*^9}, {3.5697983030322847`*^9, 
  3.569798311606552*^9}, {3.5699243901910543`*^9, 3.569924445070657*^9}, {
  3.569925058260975*^9, 3.569925059911274*^9}, {3.570617171943994*^9, 
  3.57061717879606*^9}}],

Cell[CellGroupData[{

Cell["\<\
The wave packet amplitude function \[CapitalPsi](x)\
\>", "Subtitle",
 CellFrame->{{0, 0}, {0, 2}},
 CellChangeTimes->{{3.569794954466889*^9, 3.569794980703898*^9}, {
  3.569888566129101*^9, 3.569888577206916*^9}}],

Cell[TextData[{
 "We start with the same wave function we had last week, but written to \
include time evolution.  The initial width is ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "0"], TraditionalForm]]],
 " and wave-number ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "0"], TraditionalForm]]],
 ".\n(See also Liboff pg 160)."
}], "Text",
 CellChangeTimes->{{3.5697940524157553`*^9, 3.569794054293025*^9}, {
  3.569794827861635*^9, 3.569794925241199*^9}, {3.5697952008114567`*^9, 
  3.569795274589776*^9}, {3.5697954776101522`*^9, 3.569795496557946*^9}, {
  3.569795551983498*^9, 3.5697955522346697`*^9}, {3.569795611245623*^9, 
  3.5697958197081547`*^9}, {3.569797877028349*^9, 3.569797885972062*^9}, {
  3.5697979303163643`*^9, 3.569797940706061*^9}, {3.569797972756374*^9, 
  3.5697979985762463`*^9}, {3.5697980889533*^9, 3.569798091405786*^9}, {
  3.569801453490944*^9, 3.5698014789829884`*^9}, {3.5698902432315817`*^9, 
  3.5698902613582363`*^9}, {3.5699244695049*^9, 3.56992451634505*^9}, {
  3.5707356183268013`*^9, 3.5707356463424807`*^9}, {3.570797784814362*^9, 
  3.570797814268169*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"$Assumptions", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[HBar]", ">", "0"}], ",", 
    RowBox[{"m", ">", "0"}], ",", 
    RowBox[{"d0", ">", "0"}], ",", 
    RowBox[{"Element", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "k0", ",", "\[HBar]", ",", "m", ",", "d0", ",", "x", ",", "t"}], "}"}],
       ",", "Reals"}], "]"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[CapitalPsi]", "=", 
  RowBox[{
   RowBox[{"Sqrt", "[", 
    FractionBox[
     RowBox[{"d0", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"d0", " ", "k0"}], ")"}], "2"]}]]}], 
     RowBox[{
      RowBox[{"Sqrt", "[", "\[Pi]", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["d0", "2"], "+", 
        RowBox[{"\[ImaginaryI]", " ", "t", " ", 
         RowBox[{"\[HBar]", "/", "m"}]}]}], ")"}]}]], "]"}], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox["d0", "2"], " ", "k0"}]}], ")"}], "2"], 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["d0", "2"], "+", 
         RowBox[{"\[ImaginaryI]", " ", "t", " ", 
          RowBox[{"\[HBar]", "/", "m"}]}]}], " ", ")"}]}]]}]]}]}]}], "Input",
 CellChangeTimes->{{3.5698021259386044`*^9, 3.569802196059175*^9}, 
   3.569802241930991*^9, {3.569803127694442*^9, 3.569803151868195*^9}, {
   3.570279380012034*^9, 3.570279385651637*^9}, {3.5706173760180817`*^9, 
   3.57061738053823*^9}, {3.570664101070058*^9, 3.570664101604864*^9}, {
   3.57072122759575*^9, 3.570721233594056*^9}, {3.5707215339282303`*^9, 
   3.5707215376300373`*^9}, {3.570727898966906*^9, 3.570727904510996*^9}, {
   3.570735671289872*^9, 3.5707356861600227`*^9}, {3.570735821363628*^9, 
   3.570735844342044*^9}, {3.570736253011359*^9, 3.5707362546428003`*^9}, 
   3.57073681934991*^9, {3.5707391491002207`*^9, 3.57073915914384*^9}, {
   3.570739491064499*^9, 3.570739505418272*^9}, {3.570739581716612*^9, 
   3.570739587218253*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[HBar]", ">", "0"}], ",", 
   RowBox[{"m", ">", "0"}], ",", 
   RowBox[{"d0", ">", "0"}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"k0", "|", "\[HBar]", "|", "m", "|", "d0", "|", "x", "|", "t"}], 
     ")"}], "\[Element]", "Reals"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.570664108617878*^9, 3.570721234400614*^9, 3.570721538177361*^9, 
   3.5707279056912107`*^9, 3.570731572999113*^9, 3.570735687547385*^9, {
   3.5707358222598*^9, 3.570735846207189*^9}, 3.570736008858766*^9, 
   3.570736256008273*^9, 3.570736858749383*^9, 3.570738495646237*^9, 
   3.5707391660653563`*^9, 3.570739507233264*^9, 3.5707395892971*^9, 
   3.570750508766643*^9, 3.5707980518984756`*^9, 3.57079818743332*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          SuperscriptBox["d0", "2"], " ", "k0"}], "+", "x"}], ")"}], "2"], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["d0", "2"], "+", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[HBar]"}], "m"]}], 
        ")"}]}]]}]], " ", 
   SqrtBox[
    FractionBox[
     RowBox[{"d0", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["d0", "2"]}], " ", 
        SuperscriptBox["k0", "2"]}]]}], 
     RowBox[{
      SuperscriptBox["d0", "2"], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[HBar]"}], "m"]}]]]}], 
  SuperscriptBox["\[Pi]", 
   RowBox[{"1", "/", "4"}]]]], "Output",
 CellChangeTimes->{
  3.570664108617878*^9, 3.570721234400614*^9, 3.570721538177361*^9, 
   3.5707279056912107`*^9, 3.570731572999113*^9, 3.570735687547385*^9, {
   3.5707358222598*^9, 3.570735846207189*^9}, 3.570736008858766*^9, 
   3.570736256008273*^9, 3.570736858749383*^9, 3.570738495646237*^9, 
   3.5707391660653563`*^9, 3.570739507233264*^9, 3.5707395892971*^9, 
   3.570750508766643*^9, 3.5707980518984756`*^9, 3.570798187437496*^9}]
}, Open  ]],

Cell["\<\
Let\[CloseCurlyQuote]s check the normalization...\
\>", "Text",
 CellChangeTimes->{
  3.57023292311935*^9, {3.570235151917779*^9, 3.570235194766635*^9}, {
   3.570235293629698*^9, 3.570235341416596*^9}, {3.570235429074621*^9, 
   3.570235439162318*^9}, 3.570240141377829*^9, {3.570240291435161*^9, 
   3.570240311770149*^9}, {3.570276459959118*^9, 3.5702764836351357`*^9}, {
   3.570276726910572*^9, 3.570276746092119*^9}, {3.570279020979974*^9, 
   3.57027906981744*^9}, {3.570279310443592*^9, 3.5702793228401947`*^9}, 
   3.570279455159693*^9, {3.570617311616336*^9, 3.570617315431356*^9}, {
   3.570617798004669*^9, 3.570617828224545*^9}, {3.570632548459548*^9, 
   3.570632572249084*^9}, {3.570663121317062*^9, 3.5706631373373537`*^9}, {
   3.570735775109599*^9, 3.5707357832427187`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Abs", "[", "\[CapitalPsi]", "]"}], "^", "2"}], "/.", 
    RowBox[{"{", 
     RowBox[{"t", "\[Rule]", "0"}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5707277926627417`*^9, 3.570727808135024*^9}, {
   3.570727868929932*^9, 3.57072787112018*^9}, {3.570727944640232*^9, 
   3.570727952247779*^9}, {3.570728017970263*^9, 3.5707280194432583`*^9}, 
   3.570730463963585*^9, {3.570730518442986*^9, 3.570730524191985*^9}, 
   3.5707312044532413`*^9, {3.57073126461874*^9, 3.570731264842914*^9}, {
   3.570735858910565*^9, 3.57073596016742*^9}, 3.5707368289813232`*^9}],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["\[Integral]", 
   RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
  RowBox[{
   FractionBox[
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Re", "[", 
        RowBox[{
         SuperscriptBox["d0", "2"], " ", 
         SuperscriptBox["k0", "2"]}], "]"}]}], "-", 
      RowBox[{"Re", "[", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            SuperscriptBox["d0", "2"], " ", "k0"}], "+", "x"}], ")"}], "2"], 
        SuperscriptBox["d0", "2"]], "]"}]}]], 
    RowBox[{
     SqrtBox["\[Pi]"], " ", 
     RowBox[{"Abs", "[", "d0", "]"}]}]], 
   RowBox[{"\[DifferentialD]", "x"}]}]}]], "Output",
 CellChangeTimes->{{3.5707278733418007`*^9, 3.570727879528503*^9}, 
   3.570727911205756*^9, 3.5707279482450953`*^9, {3.570728012025393*^9, 
   3.570728020639724*^9}, 3.5707304674191027`*^9, 3.570730525292179*^9, 
   3.570731269829237*^9, 3.570731386925519*^9, {3.570731561102281*^9, 
   3.570731584600725*^9}, 3.57073168150496*^9, 3.570735794878275*^9, 
   3.570735827405244*^9, {3.57073588149361*^9, 3.5707359323418007`*^9}, 
   3.5707359625480556`*^9, 3.57073686138693*^9, 3.57073849831491*^9, 
   3.5707391744765577`*^9, 3.5707395152865143`*^9, 3.570739596164157*^9, 
   3.570750511353088*^9, 3.570798054388157*^9, 3.570798189901273*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " needs some help."
}], "Text",
 CellChangeTimes->{
  3.57023292311935*^9, {3.570235151917779*^9, 3.570235194766635*^9}, {
   3.570235293629698*^9, 3.570235341416596*^9}, {3.570235429074621*^9, 
   3.570235439162318*^9}, 3.570240141377829*^9, {3.570240291435161*^9, 
   3.570240311770149*^9}, {3.570276459959118*^9, 3.5702764836351357`*^9}, {
   3.570276726910572*^9, 3.570276746092119*^9}, {3.570279020979974*^9, 
   3.57027906981744*^9}, {3.570279310443592*^9, 3.5702793228401947`*^9}, 
   3.570279455159693*^9, {3.570617311616336*^9, 3.570617315431356*^9}, {
   3.570617798004669*^9, 3.570617828224545*^9}, {3.570632548459548*^9, 
   3.570632572249084*^9}, {3.570663121317062*^9, 3.5706631373373537`*^9}, {
   3.570735775109599*^9, 3.5707357832427187`*^9}, {3.570736088147773*^9, 
   3.5707360935614433`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComplexExpand", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"Re", "[", 
     RowBox[{
      SuperscriptBox["d0", "2"], " ", 
      SuperscriptBox["k0", "2"]}], "]"}]}], "-", 
   RowBox[{"Re", "[", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         SuperscriptBox["d0", "2"], " ", "k0"}], "+", "x"}], ")"}], "2"], 
     SuperscriptBox["d0", "2"]], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.570735993528163*^9, 3.5707359978873987`*^9}, {
   3.570736119830748*^9, 3.570736163486135*^9}, 3.570739412612083*^9, {
   3.570739568953555*^9, 3.57073957193581*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   SuperscriptBox["x", "2"], 
   SuperscriptBox["d0", "2"]]}]], "Output",
 CellChangeTimes->{{3.570735977766021*^9, 3.570736013217361*^9}, {
   3.570736121997489*^9, 3.570736164446857*^9}, 3.570736861598776*^9, 
   3.570738498487883*^9, 3.5707394146175213`*^9, 3.570739599680691*^9, 
   3.570750511504985*^9, 3.570798054538218*^9, 3.570798190056773*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["\[Integral]", 
   RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
  RowBox[{
   FractionBox[
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["x", "2"], 
       SuperscriptBox["d0", "2"]]}]], 
    RowBox[{
     SqrtBox["\[Pi]"], " ", 
     RowBox[{"Abs", "[", "d0", "]"}]}]], 
   RowBox[{"\[DifferentialD]", "x"}]}]}]], "Input",
 CellChangeTimes->{{3.570736065476097*^9, 3.570736065814877*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.570736068660293*^9, 3.570736861729465*^9, 
  3.570738498619853*^9, 3.5707505116345367`*^9, 3.5707980546740637`*^9, 
  3.57079819025263*^9}]
}, Open  ]],

Cell["\<\
So, the normalization is ok.  Is this a solution to the \
Schr\[ODoubleDot]dinger equation?\
\>", "Text",
 CellChangeTimes->{
  3.57023292311935*^9, {3.570235151917779*^9, 3.570235194766635*^9}, {
   3.570235293629698*^9, 3.570235341416596*^9}, {3.570235429074621*^9, 
   3.570235439162318*^9}, 3.570240141377829*^9, {3.570240291435161*^9, 
   3.570240311770149*^9}, {3.570276459959118*^9, 3.5702764836351357`*^9}, {
   3.570276726910572*^9, 3.570276746092119*^9}, {3.570279020979974*^9, 
   3.57027906981744*^9}, {3.570279310443592*^9, 3.5702793228401947`*^9}, 
   3.570279455159693*^9, {3.570617311616336*^9, 3.570617315431356*^9}, {
   3.570617798004669*^9, 3.570617828224545*^9}, {3.570632548459548*^9, 
   3.570632572249084*^9}, {3.570663121317062*^9, 3.5706631373373537`*^9}, {
   3.570735775109599*^9, 3.5707357832427187`*^9}, {3.570736192698028*^9, 
   3.570736215094208*^9}, 3.570738690601622*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", " ", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], " ", "\[CapitalPsi]"}], "==", 
   RowBox[{
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", "\[HBar]"}], 
     RowBox[{"2", "m"}]], 
    RowBox[{
     SubscriptBox["\[PartialD]", "x"], " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], " ", "\[CapitalPsi]"}]}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5707368353599777`*^9, 3.5707368382153797`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.570736671205422*^9, 3.5707368622767878`*^9, 
  3.570738499170972*^9, 3.570750512166045*^9, 3.570798055198821*^9, 
  3.57079819081779*^9}]
}, Open  ]],

Cell["\<\
Yes!  Finally, a particle that moves!\
\>", "Text",
 CellChangeTimes->{
  3.57023292311935*^9, {3.570235151917779*^9, 3.570235194766635*^9}, {
   3.570235293629698*^9, 3.570235341416596*^9}, {3.570235429074621*^9, 
   3.570235439162318*^9}, 3.570240141377829*^9, {3.570240291435161*^9, 
   3.570240311770149*^9}, {3.570276459959118*^9, 3.5702764836351357`*^9}, {
   3.570276726910572*^9, 3.570276746092119*^9}, {3.570279020979974*^9, 
   3.57027906981744*^9}, {3.570279310443592*^9, 3.5702793228401947`*^9}, 
   3.570279455159693*^9, {3.570617311616336*^9, 3.570617315431356*^9}, {
   3.570617798004669*^9, 3.570617828224545*^9}, {3.570632548459548*^9, 
   3.570632572249084*^9}, {3.570663121317062*^9, 3.5706631373373537`*^9}, {
   3.570735775109599*^9, 3.5707357832427187`*^9}, {3.570736192698028*^9, 
   3.570736215094208*^9}, {3.570736381663752*^9, 3.570736390771688*^9}, {
   3.5707366762922707`*^9, 3.5707366788421907`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", "\[CapitalPsi]", "]"}], ",", 
        RowBox[{"Abs", "[", "\[CapitalPsi]", "]"}]}], "}"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"d0", "\[Rule]", 
         RowBox[{"10", "^", "logD"}]}], ",", 
        RowBox[{"k0", "\[Rule]", 
         SubscriptBox["k", "0"]}], ",", 
        RowBox[{"t", "\[Rule]", "tNow"}], ",", 
        RowBox[{"\[HBar]", "\[Rule]", "1"}], ",", 
        RowBox[{"m", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "5"}], ",", "20"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<\[CapitalPsi](x,t)\>\""}]}], "]"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"logD", ",", "0"}], "}"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "0.1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["k", "0"], ",", "4"}], "}"}], ",", 
     RowBox[{"-", "5"}], ",", "10", ",", "0.5", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tNow", ",", "0"}], "}"}], ",", "0", ",", "3", ",", "0.02", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5697672448000593`*^9, 3.56976732439917*^9}, {
   3.569767409628089*^9, 3.569767409706108*^9}, 3.5697938962591257`*^9, {
   3.5698019276245947`*^9, 3.569801950435587*^9}, {3.569803013409067*^9, 
   3.569803102588592*^9}, {3.56980316235565*^9, 3.569803170327304*^9}, {
   3.5698036928443727`*^9, 3.569803697961116*^9}, {3.569891555863555*^9, 
   3.569891583269918*^9}, 3.569891625869513*^9, {3.5698917626259127`*^9, 
   3.569891788119196*^9}, {3.569891889444665*^9, 3.569891947929914*^9}, {
   3.5698919820607367`*^9, 3.5698919879292183`*^9}, {3.569892071825791*^9, 
   3.569892101281225*^9}, {3.569892909246975*^9, 3.569892928227112*^9}, 
   3.569892981558735*^9, {3.569893017012245*^9, 3.5698930509998093`*^9}, {
   3.5698932404047956`*^9, 3.5698932698094177`*^9}, {3.569893397520412*^9, 
   3.569893427209515*^9}, {3.569893485060988*^9, 3.569893497885811*^9}, {
   3.5698937712598553`*^9, 3.569893851104294*^9}, {3.569894021164557*^9, 
   3.5698940217057533`*^9}, {3.569894057498232*^9, 3.569894061080235*^9}, {
   3.569894753401083*^9, 3.569894755507494*^9}, {3.569894897441921*^9, 
   3.569894991554332*^9}, {3.569895152177682*^9, 3.569895250373968*^9}, {
   3.5698952874918413`*^9, 3.569895292080295*^9}, {3.56989537447507*^9, 
   3.569895400832238*^9}, {3.569895540859371*^9, 3.569895567363639*^9}, {
   3.569895771038608*^9, 3.569895791783305*^9}, {3.5698958263011703`*^9, 
   3.569895865081922*^9}, {3.569924570691131*^9, 3.569924591266901*^9}, {
   3.570231895096363*^9, 3.5702319019695797`*^9}, {3.570232271224131*^9, 
   3.570232304024981*^9}, {3.570232358861477*^9, 3.570232404802487*^9}, {
   3.570232462342636*^9, 3.570232529337819*^9}, {3.570232566197351*^9, 
   3.5702325782602243`*^9}, {3.570293047248144*^9, 3.570293066343927*^9}, {
   3.570632647551354*^9, 3.57063281122217*^9}, {3.5706328710723257`*^9, 
   3.570632876225869*^9}, {3.570633016786304*^9, 3.570633022220664*^9}, {
   3.570662123115452*^9, 3.5706621364266043`*^9}, {3.570713968304639*^9, 
   3.570713969584886*^9}, {3.570714036315777*^9, 3.570714037882123*^9}, 
   3.570714113048849*^9, {3.570714143714857*^9, 3.5707141451412897`*^9}, {
   3.570714281044759*^9, 3.570714303209914*^9}, {3.5707333437146683`*^9, 
   3.570733346074747*^9}, {3.5707333879871073`*^9, 3.570733410164525*^9}, {
   3.570733867972386*^9, 3.5707339013315287`*^9}, {3.570733959689776*^9, 
   3.57073397252862*^9}, {3.570735021498506*^9, 3.570735023172303*^9}, {
   3.570735067790174*^9, 3.570735086210911*^9}, {3.570736399967041*^9, 
   3.570736414552052*^9}, {3.570736842484922*^9, 3.570736844940538*^9}, {
   3.570738431716868*^9, 3.570738431937752*^9}, {3.570740207382749*^9, 
   3.570740208633017*^9}, 3.57079871266138*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`logD$$ = 0.5, $CellContext`tNow$$ = 
    0., $CellContext`$569$$ = 4, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`logD$$], 0}, -1, 1, 0.1}, {{
       Hold[$CellContext`$569$$], 4, 
       RawBoxes[
        TagBox[
         SubscriptBox["k", "0"], HoldForm]]}, -5, 10, 0.5}, {{
       Hold[$CellContext`tNow$$], 0}, 0, 3, 0.02}}, Typeset`size$$ = {
    540., {178., 189.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`logD$85805$$ = 
    0, $CellContext`$569$85806$$ = 0, $CellContext`tNow$85807$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`logD$$ = 0, $CellContext`tNow$$ = 
        0, $CellContext`$569$$ = 4}, "ControllerVariables" :> {
        Hold[$CellContext`logD$$, $CellContext`logD$85805$$, 0], 
        Hold[$CellContext`$569$$, $CellContext`$569$85806$$, 0], 
        Hold[$CellContext`tNow$$, $CellContext`tNow$85807$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Plot[
        ReplaceAll[{
          Re[$CellContext`\[CapitalPsi]], 
          Abs[$CellContext`\[CapitalPsi]]}, {$CellContext`d0 -> 
          10^$CellContext`logD$$, $CellContext`k0 -> $CellContext`$569$$, \
$CellContext`t -> $CellContext`tNow$$, $CellContext`\[HBar] -> 
          1, $CellContext`m -> 1}], {$CellContext`x, -5, 20}, 
        PlotRange -> {-1, 1}, Filling -> Axis, PlotLabel -> 
        "\[CapitalPsi](x,t)"], 
      "Specifications" :> {{{$CellContext`logD$$, 0}, -1, 1, 0.1, Appearance -> 
         "Labeled"}, {{$CellContext`$569$$, 4, 
          RawBoxes[
           TagBox[
            SubscriptBox["k", "0"], HoldForm]]}, -5, 10, 0.5, Appearance -> 
         "Labeled"}, {{$CellContext`tNow$$, 0}, 0, 3, 0.02, Appearance -> 
         "Labeled"}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{604., {343., 350.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.56989556795718*^9, {3.569895781114986*^9, 3.5698957927319937`*^9}, {
   3.569895843254532*^9, 3.56989586650229*^9}, 3.569924592950029*^9, 
   3.5699734617039223`*^9, 3.570218848518984*^9, 3.570231854183236*^9, 
   3.570231915645783*^9, {3.5702323846015787`*^9, 3.570232405548897*^9}, 
   3.570232531997444*^9, 3.570232585670277*^9, 3.570232706923373*^9, 
   3.570279396353335*^9, 3.5702801627092333`*^9, 3.57029539423717*^9, 
   3.570297606496352*^9, 3.5703593169097223`*^9, 3.570617211078144*^9, {
   3.570632773189145*^9, 3.5706328126508627`*^9}, 3.570632877009987*^9, 
   3.570632933759*^9, 3.570633023212891*^9, 3.570662138444483*^9, 
   3.5707139710223417`*^9, 3.570714116012136*^9, 3.570714148971566*^9, {
   3.570714290910836*^9, 3.5707143046855803`*^9}, 3.5707333471483603`*^9, 
   3.570733816253755*^9, {3.570733869635963*^9, 3.570733902206902*^9}, {
   3.570733965263856*^9, 3.570733973528941*^9}, 3.570735023498074*^9, 
   3.570735087559689*^9, {3.570736400882374*^9, 3.570736415675478*^9}, 
   3.570736862325275*^9, 3.5707384992133017`*^9, 3.570739311119725*^9, 
   3.57075051386178*^9, 3.5707980572505627`*^9, 3.570798191487631*^9, 
   3.570798714194366*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Momentum Space", "Subtitle",
 CellFrame->{{0, 0}, {0, 2}},
 CellChangeTimes->{{3.569794954466889*^9, 3.569794980703898*^9}, {
  3.569888566129101*^9, 3.569888577206916*^9}, {3.570736988044661*^9, 
  3.570736992690291*^9}, {3.570798175105546*^9, 3.570798175848894*^9}}],

Cell["\<\
The Fourier transform looks much like the wave-packet from last week, but \
with a new time-dependent phase factor.\
\>", "Text",
 CellChangeTimes->{{3.5697940524157553`*^9, 3.569794054293025*^9}, {
  3.569794827861635*^9, 3.569794925241199*^9}, {3.5697952008114567`*^9, 
  3.569795274589776*^9}, {3.5697954776101522`*^9, 3.569795496557946*^9}, {
  3.569795551983498*^9, 3.5697955522346697`*^9}, {3.569795611245623*^9, 
  3.5697958197081547`*^9}, {3.569797877028349*^9, 3.569797885972062*^9}, {
  3.5697979303163643`*^9, 3.569797940706061*^9}, {3.569797972756374*^9, 
  3.5697979985762463`*^9}, {3.5697980889533*^9, 3.569798091405786*^9}, {
  3.569801453490944*^9, 3.5698014789829884`*^9}, {3.5698902432315817`*^9, 
  3.5698902613582363`*^9}, {3.5699244695049*^9, 3.56992451634505*^9}, {
  3.57073700679102*^9, 3.570737049854204*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["\[CapitalPsi]", "~"], "=", 
  RowBox[{
   RowBox[{"1", "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"2", "\[Pi]"}], "]"}]}], 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"\[CapitalPsi]", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "I"}], " ", "k", " ", "x"}], "]"}]}], ",", 
     RowBox[{"{", " ", 
      RowBox[{"x", ",", 
       RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.570737143273285*^9, 3.570737145528111*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SqrtBox["d0"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      SuperscriptBox["d0", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", "k0"}], ")"}], "2"]}], "-", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["k", "2"], " ", "t", " ", "\[HBar]"}], 
      RowBox[{"2", " ", "m"}]]}]]}], 
  SuperscriptBox["\[Pi]", 
   RowBox[{"1", "/", "4"}]]]], "Output",
 CellChangeTimes->{3.570736978095574*^9, 3.570738508097918*^9, 
  3.57075052287967*^9, 3.570798066411831*^9, 3.570798198939825*^9}]
}, Open  ]],

Cell["What do the expectation values look like?", "Text",
 CellChangeTimes->{{3.5697940524157553`*^9, 3.569794054293025*^9}, {
   3.569794827861635*^9, 3.569794925241199*^9}, {3.5697952008114567`*^9, 
   3.569795274589776*^9}, {3.5697954776101522`*^9, 3.569795496557946*^9}, {
   3.569795551983498*^9, 3.5697955522346697`*^9}, {3.569795611245623*^9, 
   3.5697958197081547`*^9}, {3.569797877028349*^9, 3.569797885972062*^9}, {
   3.5697979303163643`*^9, 3.569797940706061*^9}, {3.569797972756374*^9, 
   3.5697979985762463`*^9}, {3.5697980889533*^9, 3.569798091405786*^9}, {
   3.569801453490944*^9, 3.5698014789829884`*^9}, {3.5698902432315817`*^9, 
   3.5698902613582363`*^9}, {3.5699244695049*^9, 3.56992451634505*^9}, {
   3.570737059023684*^9, 3.570737106026897*^9}, {3.570737190490596*^9, 
   3.5707372044791603`*^9}, 3.570798168729454*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Momentum Statistics", "Subtitle",
 CellFrame->{{0, 0}, {0, 2}},
 CellChangeTimes->{{3.569794954466889*^9, 3.569794980703898*^9}, {
  3.569888566129101*^9, 3.569888577206916*^9}, {3.570736988044661*^9, 
  3.570736992690291*^9}, {3.570737869531645*^9, 3.570737871362238*^9}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " needs some help with the math, but the answers are the same as before."
}], "Text",
 CellChangeTimes->{{3.5697940524157553`*^9, 3.569794054293025*^9}, {
  3.569794827861635*^9, 3.569794925241199*^9}, {3.5697952008114567`*^9, 
  3.569795274589776*^9}, {3.5697954776101522`*^9, 3.569795496557946*^9}, {
  3.569795551983498*^9, 3.5697955522346697`*^9}, {3.569795611245623*^9, 
  3.5697958197081547`*^9}, {3.569797877028349*^9, 3.569797885972062*^9}, {
  3.5697979303163643`*^9, 3.569797940706061*^9}, {3.569797972756374*^9, 
  3.5697979985762463`*^9}, {3.5697980889533*^9, 3.569798091405786*^9}, {
  3.569801453490944*^9, 3.5698014789829884`*^9}, {3.5698902432315817`*^9, 
  3.5698902613582363`*^9}, {3.5699244695049*^9, 3.56992451634505*^9}, {
  3.570737059023684*^9, 3.570737106026897*^9}, {3.570737190490596*^9, 
  3.5707372044791603`*^9}, {3.570738613360776*^9, 3.570738660897234*^9}, {
  3.5707387358027067`*^9, 3.5707387483997393`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  OverscriptBox["p", "_"], "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalPsi]", "\[Conjugate]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "I"}], " ", "\[HBar]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", "\[CapitalPsi]"}]}], ")"}]}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   OverscriptBox["p", "_"], "/.", 
   RowBox[{"t", "\[Rule]", "0"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.570276797828833*^9, 3.570276892458913*^9}, {
  3.570737279900423*^9, 3.570737297521916*^9}, {3.570737432846181*^9, 
  3.570737449291909*^9}, {3.5707375623805637`*^9, 3.5707375779881887`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"k0", " ", "\[HBar]", " ", 
   SqrtBox[
    RowBox[{"m", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["d0", "2"], " ", "m"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[HBar]"}]}], ")"}]}]], " ", 
   RowBox[{"Conjugate", "[", 
    FractionBox["1", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["d0", "2"], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[HBar]"}], "m"]}]]], 
    "]"}]}], "m"]], "Output",
 CellChangeTimes->{3.5707374502208567`*^9, 3.570737580666986*^9, 
  3.570738526523693*^9, 3.570750546382518*^9, 3.570798208742607*^9}],

Cell[BoxData[
 RowBox[{"k0", " ", "\[HBar]"}]], "Output",
 CellChangeTimes->{3.5707374502208567`*^9, 3.570737580666986*^9, 
  3.570738526523693*^9, 3.570750546382518*^9, 3.5707982087449017`*^9}]
}, Open  ]],

Cell["\<\
Could <p> be a function of time?  Why not?\
\>", "Text",
 CellChangeTimes->{{3.5707387876991673`*^9, 3.570738802961382*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  OverscriptBox["p2", "_"], "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalPsi]", "\[Conjugate]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "I"}], " ", "\[HBar]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "I"}], " ", "\[HBar]", " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", "x"], " ", "\[CapitalPsi]"}]}], 
         ")"}]}]}], ")"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   OverscriptBox["p2", "_"], "/.", 
   RowBox[{"t", "\[Rule]", "0"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.570276935207274*^9, 3.5702769416733418`*^9}, {
  3.5702769840807753`*^9, 3.570277017273108*^9}, {3.570278478411003*^9, 
  3.570278491801305*^9}, {3.570737590455551*^9, 3.570737601419961*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["d0", "2"], " ", 
      SuperscriptBox["k0", "2"]}]}], ")"}], " ", 
   SuperscriptBox["\[HBar]", "2"], " ", 
   SqrtBox[
    RowBox[{"m", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["d0", "2"], " ", "m"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[HBar]"}]}], ")"}]}]], " ", 
   RowBox[{"Conjugate", "[", 
    FractionBox["1", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["d0", "2"], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[HBar]"}], "m"]}]]], 
    "]"}]}], 
  RowBox[{"2", " ", 
   SuperscriptBox["d0", "2"], " ", "m"}]]], "Output",
 CellChangeTimes->{
  3.570276936798233*^9, 3.570277019325327*^9, {3.5702784834683733`*^9, 
   3.570278500378544*^9}, 3.570279255537291*^9, 3.570279412624601*^9, 
   3.57028017797758*^9, 3.570295411648397*^9, 3.570297622942771*^9, 
   3.570359333166711*^9, 3.570737418293239*^9, 3.570737605323598*^9, 
   3.5707385310046873`*^9, 3.570750550930334*^9, 3.570798213394218*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox["d0", "2"]], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["k0", "2"]}]}], ")"}], " ", 
  SuperscriptBox["\[HBar]", "2"]}]], "Output",
 CellChangeTimes->{
  3.570276936798233*^9, 3.570277019325327*^9, {3.5702784834683733`*^9, 
   3.570278500378544*^9}, 3.570279255537291*^9, 3.570279412624601*^9, 
   3.57028017797758*^9, 3.570295411648397*^9, 3.570297622942771*^9, 
   3.570359333166711*^9, 3.570737418293239*^9, 3.570737605323598*^9, 
   3.5707385310046873`*^9, 3.570750550930334*^9, 3.570798213418149*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]p", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Sqrt", "[", 
     RowBox[{
      OverscriptBox["p2", "_"], "-", 
      SuperscriptBox[
       OverscriptBox["p", "_"], "2"]}], "]"}], "/.", 
    RowBox[{"t", "\[Rule]", "0"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.570278802868906*^9, 3.5702788637318068`*^9}, {
  3.5707375109129753`*^9, 3.570737520070861*^9}, {3.5707376195718937`*^9, 
  3.5707376340911703`*^9}}],

Cell[BoxData[
 FractionBox["\[HBar]", 
  RowBox[{
   SqrtBox["2"], " ", "d0"}]]], "Output",
 CellChangeTimes->{{3.570278847926403*^9, 3.570278864135738*^9}, 
   3.570278985348667*^9, 3.570279255709017*^9, 3.570279294434243*^9, 
   3.570279412790783*^9, 3.570280178127784*^9, 3.570295411781102*^9, 
   3.570297623087859*^9, 3.5703593333085003`*^9, {3.570737506122252*^9, 
   3.570737532862731*^9}, 3.570737636431006*^9, 3.570738531153515*^9, 
   3.570750551070109*^9, 3.57079821356383*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Energy Statistics", "Subtitle",
 CellFrame->{{0, 0}, {0, 2}},
 CellChangeTimes->{{3.569794954466889*^9, 3.569794980703898*^9}, {
  3.569888566129101*^9, 3.569888577206916*^9}, {3.570736988044661*^9, 
  3.570736992690291*^9}, {3.570737869531645*^9, 3.5707378805762663`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  OverscriptBox["E", "_"], "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalPsi]", "\[Conjugate]"}], 
     RowBox[{"(", 
      RowBox[{"I", " ", "\[HBar]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", "t"], " ", "\[CapitalPsi]"}]}], ")"}]}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   OverscriptBox["E", "_"], "/.", 
   RowBox[{"t", "\[Rule]", "0"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.570276797828833*^9, 3.570276892458913*^9}, {
  3.570737279900423*^9, 3.570737297521916*^9}, {3.570737432846181*^9, 
  3.570737449291909*^9}, {3.5707375623805637`*^9, 3.5707375779881887`*^9}, {
  3.570737748761681*^9, 3.570737776800673*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["d0", "2"], " ", 
      SuperscriptBox["k0", "2"]}]}], ")"}], " ", 
   SuperscriptBox["\[HBar]", "2"], " ", 
   SqrtBox[
    RowBox[{"m", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["d0", "2"], " ", "m"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[HBar]"}]}], ")"}]}]], " ", 
   RowBox[{"Conjugate", "[", 
    FractionBox["1", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["d0", "2"], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[HBar]"}], "m"]}]]], 
    "]"}]}], 
  RowBox[{"4", " ", 
   SuperscriptBox["d0", "2"], " ", 
   SuperscriptBox["m", "2"]}]]], "Output",
 CellChangeTimes->{3.5707374502208567`*^9, 3.570737580666986*^9, 
  3.570737779905655*^9, 3.5707385336530313`*^9, 3.570750553630254*^9, 
  3.570798221909527*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["d0", "2"], " ", 
      SuperscriptBox["k0", "2"]}]}], ")"}], " ", 
   SuperscriptBox["\[HBar]", "2"]}], 
  RowBox[{"4", " ", 
   SuperscriptBox["d0", "2"], " ", "m"}]]], "Output",
 CellChangeTimes->{3.5707374502208567`*^9, 3.570737580666986*^9, 
  3.570737779905655*^9, 3.5707385336530313`*^9, 3.570750553630254*^9, 
  3.570798221911676*^9}]
}, Open  ]],

Cell[TextData[{
 "hmmm... why isn\[CloseCurlyQuote]t that zero when ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["k", "0"], "=", "0"}], TraditionalForm]]],
 "?  If the particle has no momentum, why does it have energy?\n(The striking \
similarity to ",
 Cell[BoxData[
  OverscriptBox["p2", "_"]],
  CellChangeTimes->{{3.570276935207274*^9, 3.5702769416733418`*^9}, {
   3.5702769840807753`*^9, 3.570277017273108*^9}, {3.570278478411003*^9, 
   3.570278491801305*^9}, {3.570737590455551*^9, 3.570737601419961*^9}}],
 " is not an accident.)"
}], "Text",
 CellChangeTimes->{{3.5697940524157553`*^9, 3.569794054293025*^9}, {
  3.569794827861635*^9, 3.569794925241199*^9}, {3.5697952008114567`*^9, 
  3.569795274589776*^9}, {3.5697954776101522`*^9, 3.569795496557946*^9}, {
  3.569795551983498*^9, 3.5697955522346697`*^9}, {3.569795611245623*^9, 
  3.5697958197081547`*^9}, {3.569797877028349*^9, 3.569797885972062*^9}, {
  3.5697979303163643`*^9, 3.569797940706061*^9}, {3.569797972756374*^9, 
  3.5697979985762463`*^9}, {3.5697980889533*^9, 3.569798091405786*^9}, {
  3.569801453490944*^9, 3.5698014789829884`*^9}, {3.5698902432315817`*^9, 
  3.5698902613582363`*^9}, {3.5699244695049*^9, 3.56992451634505*^9}, {
  3.570737059023684*^9, 3.570737106026897*^9}, {3.570737190490596*^9, 
  3.5707372044791603`*^9}, {3.570738613360776*^9, 3.570738660897234*^9}, {
  3.570798309966673*^9, 3.570798333892569*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Position Statistics", "Subtitle",
 CellFrame->{{0, 0}, {0, 2}},
 CellChangeTimes->{{3.569794954466889*^9, 3.569794980703898*^9}, {
  3.569888566129101*^9, 3.569888577206916*^9}, {3.570736988044661*^9, 
  3.570736992690291*^9}, {3.570737869531645*^9, 3.570737887215805*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["x", "_"], "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalPsi]", "\[Conjugate]"}], "x", " ", "\[CapitalPsi]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.570276797828833*^9, 3.570276892458913*^9}, {
  3.570737279900423*^9, 3.570737297521916*^9}, {3.570737432846181*^9, 
  3.570737449291909*^9}, {3.5707375623805637`*^9, 3.5707375779881887`*^9}, {
  3.570737748761681*^9, 3.570737776800673*^9}, {3.570737905548719*^9, 
  3.570737928577199*^9}, {3.570737968721236*^9, 3.57073802592321*^9}, {
  3.5707381753164473`*^9, 3.570738177102068*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"k0", " ", "t", " ", "\[HBar]", " ", 
   SqrtBox[
    RowBox[{"m", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["d0", "2"], " ", "m"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[HBar]"}]}], ")"}]}]], " ", 
   RowBox[{"Conjugate", "[", 
    FractionBox["1", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["d0", "2"], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[HBar]"}], "m"]}]]], 
    "]"}]}], 
  SuperscriptBox["m", "2"]]], "Output",
 CellChangeTimes->{
  3.5707374502208567`*^9, 3.570737580666986*^9, 3.570737779905655*^9, 
   3.570737932213954*^9, {3.570737976668366*^9, 3.570738027736043*^9}, 
   3.570738545893654*^9, 3.570750556727044*^9, 3.5707982341151733`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["x", "_"], "=", 
  RowBox[{"Simplify", "[", 
   FractionBox[
    RowBox[{"k0", " ", "t", " ", "\[HBar]", " ", "m", " "}], 
    SuperscriptBox["m", "2"]], "]"}]}]], "Input",
 CellChangeTimes->{{3.570738139648707*^9, 3.5707381797079687`*^9}, {
  3.570738278584272*^9, 3.570738279335771*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"k0", " ", "t", " ", "\[HBar]"}], "m"]], "Output",
 CellChangeTimes->{3.5707381545669947`*^9, 3.570738190482211*^9, 
  3.570738279945595*^9, 3.570738546018297*^9, 3.570750556776334*^9, 
  3.570798234243191*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["x2", "_"], "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalPsi]", "\[Conjugate]"}], 
     SuperscriptBox["x", "2"], " ", "\[CapitalPsi]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.570276935207274*^9, 3.5702769416733418`*^9}, {
  3.5702769840807753`*^9, 3.570277017273108*^9}, {3.570278478411003*^9, 
  3.570278491801305*^9}, {3.570737590455551*^9, 3.570737601419961*^9}, {
  3.570737790241651*^9, 3.5707378051757307`*^9}, {3.570737956552449*^9, 
  3.570737965307148*^9}, {3.570738030812684*^9, 3.570738057769034*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SqrtBox[
    RowBox[{"m", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["d0", "2"], " ", "m"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[HBar]"}]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["d0", "4"], " ", 
      SuperscriptBox["m", "2"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["d0", "2"], " ", 
         SuperscriptBox["k0", "2"]}]}], ")"}], " ", 
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["\[HBar]", "2"]}]}], ")"}], " ", 
   RowBox[{"Conjugate", "[", 
    FractionBox["1", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["d0", "2"], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[HBar]"}], "m"]}]]], 
    "]"}]}], 
  RowBox[{"2", " ", 
   SuperscriptBox["d0", "2"], " ", 
   SuperscriptBox["m", "3"]}]]], "Output",
 CellChangeTimes->{
  3.570276936798233*^9, 3.570277019325327*^9, {3.5702784834683733`*^9, 
   3.570278500378544*^9}, 3.570279255537291*^9, 3.570279412624601*^9, 
   3.57028017797758*^9, 3.570295411648397*^9, 3.570297622942771*^9, 
   3.570359333166711*^9, 3.570737418293239*^9, 3.570737605323598*^9, 
   3.5707378187665358`*^9, {3.570738046358307*^9, 3.570738060761343*^9}, 
   3.570738547924341*^9, 3.570750558749194*^9, 3.570798236295911*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["x2", "_"], "=", 
  RowBox[{"Simplify", "[", 
   FractionBox[
    RowBox[{"m", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["d0", "4"], " ", 
        SuperscriptBox["m", "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["d0", "2"], " ", 
           SuperscriptBox["k0", "2"]}]}], ")"}], " ", 
        SuperscriptBox["t", "2"], " ", 
        SuperscriptBox["\[HBar]", "2"]}]}], ")"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox["d0", "2"], " ", 
     SuperscriptBox["m", "3"]}]], "]"}]}]], "Input",
 CellChangeTimes->{{3.570738095055422*^9, 3.570738109551251*^9}, {
   3.570738186087152*^9, 3.570738187085341*^9}, 3.5707382564470177`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["d0", "4"], " ", 
    SuperscriptBox["m", "2"]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["d0", "2"], " ", 
       SuperscriptBox["k0", "2"]}]}], ")"}], " ", 
    SuperscriptBox["t", "2"], " ", 
    SuperscriptBox["\[HBar]", "2"]}]}], 
  RowBox[{"2", " ", 
   SuperscriptBox["d0", "2"], " ", 
   SuperscriptBox["m", "2"]}]]], "Output",
 CellChangeTimes->{
  3.570738110327387*^9, 3.570738201314765*^9, {3.570738257098329*^9, 
   3.57073828360023*^9}, 3.5707385480532913`*^9, 3.570750558813323*^9, 
   3.5707982364456873`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[CapitalDelta]x", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     OverscriptBox["x2", "_"], "-", 
     SuperscriptBox[
      OverscriptBox["x", "_"], "2"]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"\[CapitalDelta]x", "==", 
   RowBox[{
    FractionBox["d0", 
     RowBox[{" ", 
      SqrtBox["2"]}]], 
    SqrtBox[
     RowBox[{"1", "+", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"t", " ", "\[HBar]"}], 
         RowBox[{" ", 
          RowBox[{
           SuperscriptBox["d0", "2"], " ", "m"}]}]], ")"}], "2"]}]]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.570278802868906*^9, 3.5702788637318068`*^9}, {
  3.5707375109129753`*^9, 3.570737520070861*^9}, {3.5707376195718937`*^9, 
  3.5707376340911703`*^9}, {3.570737823374797*^9, 3.570737826781114*^9}, {
  3.570738064515901*^9, 3.570738073977846*^9}, {3.5707504626435738`*^9, 
  3.5707504965915403`*^9}}],

Cell[BoxData[
 FractionBox[
  SqrtBox[
   RowBox[{
    SuperscriptBox["d0", "2"], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["\[HBar]", "2"]}], 
     RowBox[{
      SuperscriptBox["d0", "2"], " ", 
      SuperscriptBox["m", "2"]}]]}]], 
  SqrtBox["2"]]], "Output",
 CellChangeTimes->{{3.570278847926403*^9, 3.570278864135738*^9}, 
   3.570278985348667*^9, 3.570279255709017*^9, 3.570279294434243*^9, 
   3.570279412790783*^9, 3.570280178127784*^9, 3.570295411781102*^9, 
   3.570297623087859*^9, 3.5703593333085003`*^9, {3.570737506122252*^9, 
   3.570737532862731*^9}, 3.570737636431006*^9, 3.570737829788784*^9, 
   3.570738076135763*^9, 3.570738207185647*^9, 3.5707382892777987`*^9, 
   3.5707385481833887`*^9, 3.570750497139538*^9, 3.5707505589460993`*^9, 
   3.570798236591613*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.570278847926403*^9, 3.570278864135738*^9}, 
   3.570278985348667*^9, 3.570279255709017*^9, 3.570279294434243*^9, 
   3.570279412790783*^9, 3.570280178127784*^9, 3.570295411781102*^9, 
   3.570297623087859*^9, 3.5703593333085003`*^9, {3.570737506122252*^9, 
   3.570737532862731*^9}, 3.570737636431006*^9, 3.570737829788784*^9, 
   3.570738076135763*^9, 3.570738207185647*^9, 3.5707382892777987`*^9, 
   3.5707385481833887`*^9, 3.570750497139538*^9, 3.5707505589460993`*^9, 
   3.570798237213606*^9}]
}, Open  ]],

Cell["And the uncertainty product?", "Text",
 CellChangeTimes->{{3.5697940524157553`*^9, 3.569794054293025*^9}, {
  3.569794827861635*^9, 3.569794925241199*^9}, {3.5697952008114567`*^9, 
  3.569795274589776*^9}, {3.5697954776101522`*^9, 3.569795496557946*^9}, {
  3.569795551983498*^9, 3.5697955522346697`*^9}, {3.569795611245623*^9, 
  3.5697958197081547`*^9}, {3.569797877028349*^9, 3.569797885972062*^9}, {
  3.5697979303163643`*^9, 3.569797940706061*^9}, {3.569797972756374*^9, 
  3.5697979985762463`*^9}, {3.5697980889533*^9, 3.569798091405786*^9}, {
  3.569801453490944*^9, 3.5698014789829884`*^9}, {3.5698902432315817`*^9, 
  3.5698902613582363`*^9}, {3.5699244695049*^9, 3.56992451634505*^9}, {
  3.570737059023684*^9, 3.570737106026897*^9}, {3.570737190490596*^9, 
  3.5707372044791603`*^9}, {3.570738613360776*^9, 3.570738660897234*^9}, {
  3.57073884613826*^9, 3.570738874039909*^9}, {3.570739051975142*^9, 
  3.5707390563663*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FullSimplify", "[", 
  RowBox[{"\[CapitalDelta]x", " ", "\[CapitalDelta]p"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"\[CapitalDelta]x", " ", "\[CapitalDelta]p"}], "==", 
   RowBox[{
    FractionBox["\[HBar]", 
     RowBox[{" ", "2"}]], " ", 
    SqrtBox[
     RowBox[{"1", "+", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"t", " ", "\[HBar]"}], 
         RowBox[{" ", 
          RowBox[{
           SuperscriptBox["d0", "2"], " ", "m"}]}]], ")"}], "2"]}]]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.570278802868906*^9, 3.5702788637318068`*^9}, {
  3.5707375109129753`*^9, 3.570737520070861*^9}, {3.5707376195718937`*^9, 
  3.5707376340911703`*^9}, {3.570737823374797*^9, 3.570737826781114*^9}, {
  3.570738064515901*^9, 3.570738073977846*^9}, {3.570738861155245*^9, 
  3.570739025358491*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[HBar]", " ", 
   SqrtBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["d0", "4"], " ", 
      SuperscriptBox["m", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["t", "2"], " ", 
      SuperscriptBox["\[HBar]", "2"]}]}]]}], 
  RowBox[{"2", " ", 
   SuperscriptBox["d0", "2"], " ", "m"}]]], "Output",
 CellChangeTimes->{3.570738869951228*^9, 3.570739026755044*^9, 
  3.570750559580497*^9, 3.570798237248576*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.570738869951228*^9, 3.570739026755044*^9, 
  3.570750559580497*^9, 3.570798237901614*^9}]
}, Open  ]],

Cell["... grows with time!", "Text",
 CellChangeTimes->{{3.5697940524157553`*^9, 3.569794054293025*^9}, {
  3.569794827861635*^9, 3.569794925241199*^9}, {3.5697952008114567`*^9, 
  3.569795274589776*^9}, {3.5697954776101522`*^9, 3.569795496557946*^9}, {
  3.569795551983498*^9, 3.5697955522346697`*^9}, {3.569795611245623*^9, 
  3.5697958197081547`*^9}, {3.569797877028349*^9, 3.569797885972062*^9}, {
  3.5697979303163643`*^9, 3.569797940706061*^9}, {3.569797972756374*^9, 
  3.5697979985762463`*^9}, {3.5697980889533*^9, 3.569798091405786*^9}, {
  3.569801453490944*^9, 3.5698014789829884`*^9}, {3.5698902432315817`*^9, 
  3.5698902613582363`*^9}, {3.5699244695049*^9, 3.56992451634505*^9}, {
  3.570737059023684*^9, 3.570737106026897*^9}, {3.570737190490596*^9, 
  3.5707372044791603`*^9}, {3.570738613360776*^9, 3.570738660897234*^9}, {
  3.57073884613826*^9, 3.570738874039909*^9}, {3.570739043199897*^9, 
  3.570739046775375*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1255, 1005},
WindowMargins->{{5, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
CellContext->Notebook,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.5, 1.5 Inherited],
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (August 26, \
2012)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "PastelColor.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 206, 3, 90, "Title"],
Cell[788, 27, 390, 7, 39, "Text"],
Cell[CellGroupData[{
Cell[1203, 38, 224, 5, 46, "Subtitle"],
Cell[1430, 45, 1109, 22, 64, "Text"],
Cell[CellGroupData[{
Cell[2564, 71, 2180, 54, 140, "Input"],
Cell[4747, 127, 756, 16, 58, "Output"],
Cell[5506, 145, 1414, 39, 144, "Output"]
}, Open  ]],
Cell[6935, 187, 802, 13, 39, "Text"],
Cell[CellGroupData[{
Cell[7762, 204, 764, 16, 55, "Input"],
Cell[8529, 222, 1434, 34, 115, "Output"]
}, Open  ]],
Cell[9978, 259, 878, 16, 39, "Text"],
Cell[CellGroupData[{
Cell[10881, 279, 684, 19, 94, "Input"],
Cell[11568, 300, 397, 8, 85, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12002, 313, 488, 15, 115, "Input"],
Cell[12493, 330, 189, 3, 55, "Output"]
}, Open  ]],
Cell[12697, 336, 916, 15, 39, "Text"],
Cell[CellGroupData[{
Cell[13638, 355, 478, 14, 82, "Input"],
Cell[14119, 371, 190, 3, 55, "Output"]
}, Open  ]],
Cell[14324, 377, 940, 15, 39, "Text"],
Cell[CellGroupData[{
Cell[15289, 396, 4394, 84, 150, "Input"],
Cell[19686, 482, 3856, 71, 732, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[23591, 559, 274, 4, 46, "Subtitle"],
Cell[23868, 565, 844, 13, 39, "Text"],
Cell[CellGroupData[{
Cell[24737, 582, 556, 17, 58, "Input"],
Cell[25296, 601, 677, 20, 100, "Output"]
}, Open  ]],
Cell[25988, 624, 846, 11, 39, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26871, 640, 279, 4, 46, "Subtitle"],
Cell[27153, 646, 1007, 16, 39, "Text"],
Cell[CellGroupData[{
Cell[28185, 666, 828, 23, 79, "Input"],
Cell[29016, 691, 659, 19, 121, "Output"],
Cell[29678, 712, 194, 3, 55, "Output"]
}, Open  ]],
Cell[29887, 718, 134, 3, 39, "Text"],
Cell[CellGroupData[{
Cell[30046, 725, 1003, 28, 91, "Input"],
Cell[31052, 755, 1124, 31, 123, "Output"],
Cell[32179, 788, 636, 15, 81, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32852, 808, 474, 12, 64, "Input"],
Cell[33329, 822, 488, 9, 84, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[33866, 837, 279, 4, 46, "Subtitle"],
Cell[CellGroupData[{
Cell[34170, 845, 854, 23, 89, "Input"],
Cell[35027, 870, 937, 29, 123, "Output"],
Cell[35967, 901, 466, 13, 87, "Output"]
}, Open  ]],
Cell[36448, 917, 1416, 26, 67, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37901, 948, 279, 4, 46, "Subtitle"],
Cell[CellGroupData[{
Cell[38205, 956, 730, 17, 55, "Input"],
Cell[38938, 975, 793, 22, 122, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39768, 1002, 329, 8, 84, "Input"],
Cell[40100, 1012, 248, 5, 78, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40385, 1022, 705, 16, 64, "Input"],
Cell[41093, 1040, 1425, 40, 123, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42555, 1085, 794, 23, 91, "Input"],
Cell[43352, 1110, 662, 20, 87, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44051, 1135, 1004, 29, 148, "Input"],
Cell[45058, 1166, 839, 20, 120, "Output"],
Cell[45900, 1188, 553, 8, 55, "Output"]
}, Open  ]],
Cell[46468, 1199, 942, 13, 39, "Text"],
Cell[CellGroupData[{
Cell[47435, 1216, 909, 24, 140, "Input"],
Cell[48347, 1242, 456, 14, 94, "Output"],
Cell[48806, 1258, 142, 2, 55, "Output"]
}, Open  ]],
Cell[48963, 1263, 936, 13, 39, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
